#
# Conditional build:
%bcond_without	doc	# Sphinx documentation
%bcond_without	tests	# unit tests

%define		module  acme
Summary:	Python library for the ACME protocol
Summary(pl.UTF-8):	Biblioteka Pythona do protokołu ACME
Name:		python3-%{module}
Version:	4.0.0
Release:	1
License:	Apache v2.0
Group:		Libraries/Python
#Source0Download: https://pypi.org/simple/acme/
Source0:	https://files.pythonhosted.org/packages/source/a/acme/%{module}-%{version}.tar.gz
# Source0-md5:	96283d18a19754cf0e489359b6204da8
URL:		https://pypi.org/project/acme/
BuildRequires:	python3-devel >= 1:3.7
BuildRequires:	python3-setuptools >= 1:41.6
BuildRequires:	rpm-pythonprov
BuildRequires:	rpmbuild(macros) >= 1.714
%if %{with doc} || %{with tests}
BuildRequires:	python3-cryptography >= 43.0.0
BuildRequires:	python3-josepy >= 2.0.0
BuildRequires:	python3-pyOpenSSL >= 25.0
BuildRequires:	python3-pyrfc3339
BuildRequires:	python3-pytz >= 2019.3
BuildRequires:	python3-requests >= 2.20.0
%endif
%if %{with tests}
BuildRequires:	python3-pytest
%endif
%if %{with doc}
BuildRequires:	python3-sphinx_rtd_theme
BuildRequires:	sphinx-pdg-3 >= 1.0
%endif
Suggests:	python3-acme-doc
BuildArch:	noarch
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
Python library for use of the Automatic Certificate Management
Environment protocol as defined by the IETF. It's used by the Let's
Encrypt project.

%description -l pl.UTF-8
Biblioteka Pythona do korzystania z protokołu Automatic Certificate
Management Environment (środowiska automatycznego zarządzania
certyfikatami) zdefiniowanego przez IETF. Jest używana przez projekt
Let's Encrypt.

%package doc
Summary:	Documentation for python-acme library
Summary(pl.UTF-8):	Dokumentacja do biblioteki python-acme
Group:		Documentation

%description doc
Documentation for the ACME Python library.

%description doc -l pl.UTF-8
Dokumentacja do biblioteki Pythona ACME.

%prep
%setup -q -n %{module}-%{version}

%build
%py3_build

%if %{with tests}
PYTEST_DISABLE_PLUGIN_AUTOLOAD=1 \
PYTHONPATH=$(pwd)/build-3 \
%{__python3} -m pytest build-3
%endif

%if %{with doc}
%{__make} -C docs html \
	SPHINXBUILD=sphinx-build-3
%endif

%install
rm -rf $RPM_BUILD_ROOT

%py3_install

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(644,root,root,755)
%doc README.rst
%{py3_sitescriptdir}/%{module}
%{py3_sitescriptdir}/%{module}-%{version}-py*.egg-info

%if %{with doc}
%files doc
%defattr(644,root,root,755)
%doc docs/_build/html/{_modules,_static,api,man,*.html,*.js}
%endif
%changelog
* Wed Apr 30 2025 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/python3-acme.git;a=log;h=master

* Wed Apr 30 2025 Arkadiusz Miśkiewicz <arekm@maven.pl> 6ae000f
- Up to 4.0.0

* Tue Mar 11 2025 Jan Rękorajski <baggins@pld-linux.org> 92a8deb
- doc/test rebuild for python 3.13

* Mon Mar 10 2025 Jan Rękorajski <baggins@pld-linux.org> b755fb7
- python 3.13 rebuild

* Wed Jan 25 2023 Jakub Bogusz <qboosh@pld-linux.org> 5ced983
- updated to 1.32.0

* Wed Jan 25 2023 Jakub Bogusz <qboosh@pld-linux.org> c8a300c
- don't manually duplicate autogenerated dependencies

* Wed Jan 25 2023 Jakub Bogusz <qboosh@pld-linux.org> e5ec42e
- moved from python-acme.spec, 1.27.0 requires python 3.7+; fixed tests and dependencies

* Wed Jan 25 2023 Jakub Bogusz <qboosh@pld-linux.org> e05b517
- pl, updated URLs

* Sat May 21 2022 Jan Rękorajski <baggins@pld-linux.org> 465cc2e
- up to 1.27.0

* Wed Mar 30 2022 Jan Rękorajski <baggins@pld-linux.org> d223565
- rebuild with tests and docs

* Sat Mar 26 2022 Jan Rękorajski <baggins@pld-linux.org> dce9a5e
- rebuild with python 3.10

* Fri Mar 25 2022 Jan Rękorajski <baggins@pld-linux.org> 3e4b7b5
- rebuild with python 3.10

* Sun Feb 28 2021 Jan Rękorajski <baggins@pld-linux.org> 8a4b99a
- release 4 (by relup.sh)

* Sun Feb 28 2021 Jan Rękorajski <baggins@pld-linux.org> d1b2167
- update BRs

* Sun Feb 28 2021 Jan Rękorajski <baggins@pld-linux.org> 764a619
- release 3 (by relup.sh)

* Sun Mar 15 2020 Jan Rękorajski <baggins@pld-linux.org> 8d4a882
- release 2 (by relup.sh)

* Sat Feb 08 2020 Arkadiusz Miśkiewicz <arekm@maven.pl> 487bfed
- up to 1.2.0

* Sun Jul 29 2018 Jan Rękorajski <baggins@pld-linux.org> f9452c0
- remove leftovers of fedora cruft (don't unbundle something that does not exists in PLD)
- disable tests (test system cannot cope with build subdirs)
- rel 3

* Sun Jul 29 2018 Jan Rękorajski <baggins@pld-linux.org> a178670
- removed fedora junk from doc package
- rel 2

* Sun Jul 15 2018 Arkadiusz Miśkiewicz <arekm@maven.pl> 5244685
- up to 0.26.0

* Fri Dec 04 2015 Elan Ruusamäe <glen@delfi.ee> 6851879
- pldize ndg httpsclient package name

